@@ -1,5 +1,8 @@
 package SHARYANTO::HTML::Extract::ImageLinks;
 
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.77'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
@@ -11,8 +14,6 @@ use Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(extract_image_links);
 
-our $VERSION = '0.67'; # VERSION
-
 our %SPEC;
 
 $SPEC{extract_image_links} = {
@@ -85,7 +86,11 @@ SHARYANTO::HTML::Extract::ImageLinks - Extract image links from HTML document
 
 =head1 VERSION
 
-version 0.67
+This document describes version 0.77 of SHARYANTO::HTML::Extract::ImageLinks (from Perl distribution SHARYANTO-Utils), released on 2015-09-04.
+
+=head1 SEE ALSO
+
+L<SHARYANTO>
 
 =head1 FUNCTIONS
 
@@ -102,25 +107,24 @@ Arguments ('*' denotes required arguments):
 
 =item * B<base> => I<str>
 
-Extract image links from HTML document.
-
-Either specify either url, html.
+base URL for images.
 
 =item * B<html>* => I<str>
 
-Extract image links from HTML document.
-
-Either specify either url, html.
+HTML document to extract from.
 
 =back
 
-Return value:
+Returns an enveloped result (an array).
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
 
-=head1 SEE ALSO
-
-L<SHARYANTO>
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -128,7 +132,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/SHARYANTO-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Utils>.
+Source repository is at L<https://github.com/perlancar/perl-SHARYANTO-Utils>.
 
 =head1 BUGS
 
@@ -140,11 +144,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
