@@ -5,7 +5,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(detect_http_ua_simple);
 
-our $VERSION = '0.67'; # VERSION
+our $VERSION = '0.77'; # VERSION
 
 our %SPEC;
 
@@ -60,11 +60,11 @@ _
         schema => 'hash*',
     },
     links => [
-        {url => "pm://HTML::ParseBrowser", tags => ['see']},
-        {url => "pm://HTTP::BrowserDetect", tags => ['see']},
-        {url => "pm://HTTP::DetectUserAgent", tags => ['see']},
-        {url => "pm://Parse::HTTP::UserAgent", tags => ['see']},
-        {url => "pm://HTTP::headers::UserAgent", tags => ['see']},
+        {url => "pm:HTML::ParseBrowser"},
+        {url => "pm:HTTP::BrowserDetect"},
+        {url => "pm:HTTP::DetectUserAgent"},
+        {url => "pm:Parse::HTTP::UserAgent"},
+        {url => "pm:HTTP::headers::UserAgent"},
     ],
     args_as => "array",
     result_naked => 0,
@@ -121,19 +121,50 @@ SHARYANTO::HTTP::DetectUA::Simple - A very simple and generic browser detection
 
 =head1 VERSION
 
-version 0.67
+This document describes version 0.77 of SHARYANTO::HTTP::DetectUA::Simple (from Perl distribution SHARYANTO-Utils), released on 2015-09-04.
+
+=head1 SEE ALSO
+
+L<SHARYANTO>
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/SHARYANTO-Utils>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-SHARYANTO-Utils>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=SHARYANTO-Utils>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by perlancar@cpan.org.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =head1 DESCRIPTION
 
 
 I needed a simple and fast routine which can detect whether HTTP client is a GUI
 browser (like Chrome or Firefox), a text browser (like Lynx or Links), or
-neither (like curl, or L). Hence, this module.
+neither (like curl, or L<LWP>). Hence, this module.
 
 =head1 FUNCTIONS
 
 
-=head2 detect_http_ua_simple(@args) -> [status, msg, result, meta]
+=head2 detect_http_ua_simple($env) -> [status, msg, result, meta]
 
 Detect whether HTTP client is a GUI/TUI browser.
 
@@ -145,15 +176,9 @@ Currently these heuristic rules are used:
 
 =over
 
-=item *
-
-check popular browser markers in User-Agent header (e.g. 'Chrome', 'Opera');
-
-
-=item *
-
-check Accept header for 'image/';
+=item * check popular browser markers in User-Agent header (e.g. 'Chrome', 'Opera');
 
+=item * check Accept header for 'image/';
 
 =back
 
@@ -166,66 +191,48 @@ Arguments ('*' denotes required arguments):
 
 =item * B<env> => I<any>
 
-Detect whether HTTP client is a GUI/TUI browser.
+CGI-compatible environment, e.g. \%ENV or PSGI's $env.
 
-This function is a simple and fast routine to detect whether HTTP client is a
-GUI browser (like Chrome or Firefox), a text-based browser (like Lynx or Links),
-or neither (like curl or LWP). Extra information can be provided in the future.
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (hash)
 
-Currently these heuristic rules are used:
 
 =over
 
-=item *
+=item * 'is_gui_browser' key will be set to true if HTTP client is a GUI browser.
 
-check popular browser markers in User-Agent header (e.g. 'Chrome', 'Opera');
-
-
-=item *
-
-check Accept header for 'image/';
+=item * 'is_text_browser' key will be set to true if HTTP client is a text/TUI
+browser.
 
+=item * 'is_browser' key will be set to true if either 'is_gui_browser' or
+'is_text_browser' is set to true.
 
 =back
 
-It is several times faster than the other equivalent Perl modules, this is
-because it does significantly less.
+See also:
+
+=over
+
+* L<HTML::ParseBrowser>
+
+* L<HTTP::BrowserDetect>
+
+* L<HTTP::DetectUserAgent>
+
+* L<Parse::HTTP::UserAgent>
+
+* L<HTTP::headers::UserAgent>
 
 =back
 
-Return value:
-
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
-
-=head1 SEE ALSO
-
-L<SHARYANTO>
-
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/SHARYANTO-Utils>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Utils>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=SHARYANTO-Utils>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHOR
-
-Steven Haryanto <stevenharyanto@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Steven Haryanto.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
